#ifndef NT2_INCLUDE_FUNCTIONS_CTZ_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CTZ_HPP_INCLUDED

#include <nt2/bitwise/include/functions/ctz.hpp>

#endif
